@@ -184,7 +184,7 @@ class GUI:
     def about_page(self, widget):
         aboutdialog = gtk.AboutDialog()        
         aboutdialog.set_name("CON900")
-        aboutdialog.set_version("0.0.9-1")
+        aboutdialog.set_version("0.0.9-2")
         aboutdialog.set_comments("This application was created to ease the customization of OptimizeN900 Script. It's coded in PyGTK.")
         aboutdialog.set_license("GNU LGPL 2.1")
         aboutdialog.set_website("humblecon900.garage.maemo.org")
@@ -227,27 +227,27 @@ class GUI:
         vbox_left.pack_start(label)
         
         button1 =gtk.Button("TEST")
-        button1.connect("pressed", self.Test_Script)
+        button1.connect("clicked", self.Test_Script)
         vbox_left.pack_start(button1)
 
         button2 = gtk.Button("Find")
-        button2.connect("pressed", self.Find_Process)
+        button2.connect("clicked", self.Find_Process)
         vbox_middle.pack_start(button2) 
 
 	button3 = gtk.Button("View")
-        button3.connect("pressed", self.View_Script)
+        button3.connect("clicked", self.View_Script)
         vbox_right.pack_start(button3) 
 
 	button4 = gtk.Button("Restore")
-        button4.connect("pressed", self.Restore_script)
+        button4.connect("clicked", self.Restore_script)
         vbox_right.pack_start(button4)
 
         button5 = gtk.Button("About")
-        button5.connect("pressed", self.about_page)
+        button5.connect("clicked", self.about_page)
         vbox_right.pack_start(button5)
                 
         button6 = gtk.Button("Edit")
-        button6.connect("pressed", self.Edit_Script)
+        button6.connect("clicked", self.Edit_Script)
         vbox_middle.pack_end(button6)
 
         self.window.add(hbox)
